Struct FixedArray
#[repr(transparent)]pub struct FixedArray<T, const N: usize>(pub [T; N]);Expand description
A fixed-size array encoded and decoded with a VarInt length prefix.
This is used when the length of the array is known statically, but a length prefix is needed anyway.
Tuple Fields
0: [T; N]Trait Implementations
impl<T, const N: usize> Clone for FixedArray<T, N>where
T: Clone,
impl<T, const N: usize> Clone for FixedArray<T, N>where
T: Clone,
fn clone(&self) -> FixedArray<T, N>
fn clone(&self) -> FixedArray<T, N>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl<T, const N: usize> Debug for FixedArray<T, N>where
T: Debug,
impl<T, const N: usize> Debug for FixedArray<T, N>where
T: Debug,
impl<'a, T, const N: usize> Decode<'a> for FixedArray<T, N>where
T: Decode<'a>,
impl<'a, T, const N: usize> Decode<'a> for FixedArray<T, N>where
T: Decode<'a>,
impl<T, const N: usize> Encode for FixedArray<T, N>where
T: Encode,
impl<T, const N: usize> Encode for FixedArray<T, N>where
T: Encode,
impl<T, const N: usize> From<[T; N]> for FixedArray<T, N>
impl<T, const N: usize> From<[T; N]> for FixedArray<T, N>
fn from(value: [T; N]) -> FixedArray<T, N>
fn from(value: [T; N]) -> FixedArray<T, N>
Converts to this type from the input type.
impl<T, const N: usize> Hash for FixedArray<T, N>where
T: Hash,
impl<T, const N: usize> Hash for FixedArray<T, N>where
T: Hash,
impl<T, const N: usize> Ord for FixedArray<T, N>where
T: Ord,
impl<T, const N: usize> Ord for FixedArray<T, N>where
T: Ord,
fn cmp(&self, other: &FixedArray<T, N>) -> Ordering
fn cmp(&self, other: &FixedArray<T, N>) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
impl<T, const N: usize> PartialEq for FixedArray<T, N>where
T: PartialEq,
impl<T, const N: usize> PartialEq for FixedArray<T, N>where
T: PartialEq,
impl<T, const N: usize> PartialOrd for FixedArray<T, N>where
T: PartialOrd,
impl<T, const N: usize> PartialOrd for FixedArray<T, N>where
T: PartialOrd,
impl<T, const N: usize> Copy for FixedArray<T, N>where
T: Copy,
impl<T, const N: usize> Eq for FixedArray<T, N>where
T: Eq,
impl<T, const N: usize> StructuralPartialEq for FixedArray<T, N>