Struct VarInt
#[repr(transparent)]pub struct VarInt(pub i32);Expand description
An i32 encoded with variable length.
Tuple Fields
0: i32Implementations
impl VarInt
impl VarInt
pub const MAX_SIZE: usize = 5
pub const MAX_SIZE: usize = 5
The maximum number of bytes a VarInt could occupy when read from and
written to the Minecraft protocol.
pub const fn written_size(self) -> usize
pub const fn written_size(self) -> usize
Returns the exact number of bytes this varint will write when
[Encode::encode] is called, assuming no error occurs.
This is the size of “canonical” (non-padded) encoding for this
value, not necessarily the number of bytes that were consumed
while decoding it. Minecraft VarInts may be padded by using
more continuation bytes than the value requires, so callers that
need the decoded wire length should compare the input slice length
before and after decoding instead.
pub fn decode_partial<R>(r: R) -> Result<i32, VarIntDecodeError>where
R: Read,